==> developer-center-api-3.6.83-20220531.032540-5-sources.jar: cn/com/duiba/developer/center/api/domain/dto/purchase/PurchaseAdvDetailDTO.java <==
package cn.com.duiba.developer.center.api.domain.dto.purchase;

import java.io.Serializable;
import java.util.Date;

/**
* 广告详情
*/
public class PurchaseAdvDetailDTO implements Serializable {

    /**
    * 
    */
    private Long id;

    /**
    * 广告标题
    */
    private String title;

    /**
     * 广告位id
     */
    private Long advConfigId;
    /**
    * 缩略图
    */
    private String smallUrl;

    /**
    * 主图
    */
    private String mainUrl;

    /**
    * 链接
    */
    private String link;


    /**
    * 描述
    */
    private String description;
    /**
     * 广告位名称
     */
    private String advConfigTitle;
    /**
     * 上线时间
     */
    private String createTime;

    public String getAdvConfigTitle() {
        return advConfigTitle;
    }

    public void setAdvConfigTitle(String advConfigTitle) {
        this.advConfigTitle = advConfigTitle;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public Long getAdvConfigId() {
        return advConfigId;
    }

    public void setAdvConfigId(Long advConfigId) {
        this.advConfigId = advConfigId;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTitle() {
        return title;
    }

    public void setSmallUrl(String smallUrl) {
        this.smallUrl = smallUrl;
    }

    public String getSmallUrl() {
        return smallUrl;
    }

    public void setMainUrl(String mainUrl) {
        this.mainUrl = mainUrl;
    }

    public String getMainUrl() {
        return mainUrl;
    }

    public void setLink(String link) {
        this.link = link;
    }

    public String getLink() {
        return link;
    }


    public void setDescription(String description) {
        this.description = description;
    }

    public String getDescription() {
        return description;
    }


}

==> developer-center-api-3.9.42-sources.jar: cn/com/duiba/developer/center/api/domain/dto/purchase/PurchaseAdvDetailDTO.java <==
package cn.com.duiba.developer.center.api.domain.dto.purchase;

import java.io.Serializable;
import java.util.Date;

/**
* 广告详情
*/
public class PurchaseAdvDetailDTO implements Serializable {

    /**
    * 
    */
    private Long id;

    /**
    * 广告标题
    */
    private String title;

    /**
     * 广告位id
     */
    private Long advConfigId;
    /**
    * 缩略图
    */
    private String smallUrl;

    /**
    * 主图
    */
    private String mainUrl;

    /**
    * 链接
    */
    private String link;


    /**
    * 描述
    */
    private String description;
    /**
     * 广告位名称
     */
    private String advConfigTitle;
    /**
     * 上线时间
     */
    private String createTime;
    /**
     * 是否置顶 0否1是
     */
    private Integer top;
    /**
     * 置顶时间
     */
    private Date topTime;

    public Integer getTop() {
        return top;
    }

    public void setTop(Integer top) {
        this.top = top;
    }

    public Date getTopTime() {
        return topTime;
    }

    public void setTopTime(Date topTime) {
        this.topTime = topTime;
    }

    public String getAdvConfigTitle() {
        return advConfigTitle;
    }

    public void setAdvConfigTitle(String advConfigTitle) {
        this.advConfigTitle = advConfigTitle;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public Long getAdvConfigId() {
        return advConfigId;
    }

    public void setAdvConfigId(Long advConfigId) {
        this.advConfigId = advConfigId;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTitle() {
        return title;
    }

    public void setSmallUrl(String smallUrl) {
        this.smallUrl = smallUrl;
    }

    public String getSmallUrl() {
        return smallUrl;
    }

    public void setMainUrl(String mainUrl) {
        this.mainUrl = mainUrl;
    }

    public String getMainUrl() {
        return mainUrl;
    }

    public void setLink(String link) {
        this.link = link;
    }

    public String getLink() {
        return link;
    }


    public void setDescription(String description) {
        this.description = description;
    }

    public String getDescription() {
        return description;
    }


}
